@@ -6,8 +6,8 @@ from cmd import Cmd
 
 from setux.main import banner
 from setux.logger import logger
+from setux.commands import commands
 from .helps import helps
-from . import commands
 
 
 def help(cmd=None):
